==> dataspex-2025.06.7.jar: public/app/cljs-runtime/dataspex.views.js <==
goog.provide('dataspex.views');
dataspex.views.inline = new cljs.core.Keyword("dataspex.views","inline","dataspex.views/inline",446683124);
dataspex.views.dictionary = new cljs.core.Keyword("dataspex.views","dictionary","dataspex.views/dictionary",-1052047971);
dataspex.views.table = new cljs.core.Keyword("dataspex.views","table","dataspex.views/table",394751342);
dataspex.views.source = new cljs.core.Keyword("dataspex.views","source","dataspex.views/source",-1131308809);
dataspex.views.views = cljs.core.PersistentHashSet.createAsIfByAssoc([dataspex.views.inline,dataspex.views.table,dataspex.views.dictionary,dataspex.views.source]);
dataspex.views.max_items = (100);
dataspex.views.max_count = (1000);
dataspex.views.get_pagination = (function dataspex$views$get_pagination(p__68563){
var map__68564 = p__68563;
var map__68564__$1 = cljs.core.__destructure_map(map__68564);
var pagination = cljs.core.get.cljs$core$IFn$_invoke$arity$2(map__68564__$1,new cljs.core.Keyword("dataspex","pagination","dataspex/pagination",1579821342));
var path = cljs.core.get.cljs$core$IFn$_invoke$arity$2(map__68564__$1,new cljs.core.Keyword("dataspex","path","dataspex/path",-1944358954));
return new cljs.core.PersistentArrayMap(null, 2, [new cljs.core.Keyword(null,"page-size","page-size",223836073),(function (){var or__5002__auto__ = cljs.core.get_in.cljs$core$IFn$_invoke$arity$2(pagination,new cljs.core.PersistentVector(null, 2, 5, cljs.core.PersistentVector.EMPTY_NODE, [path,new cljs.core.Keyword(null,"page-size","page-size",223836073)], null));
if(cljs.core.truth_(or__5002__auto__)){
return or__5002__auto__;
} else {
var or__5002__auto____$1 = new cljs.core.Keyword(null,"page-size","page-size",223836073).cljs$core$IFn$_invoke$arity$1(pagination);
if(cljs.core.truth_(or__5002__auto____$1)){
return or__5002__auto____$1;
} else {
return dataspex.views.max_items;
}
}
})(),new cljs.core.Keyword(null,"offset","offset",296498311),(function (){var or__5002__auto__ = cljs.core.get_in.cljs$core$IFn$_invoke$arity$2(pagination,new cljs.core.PersistentVector(null, 2, 5, cljs.core.PersistentVector.EMPTY_NODE, [path,new cljs.core.Keyword(null,"offset","offset",296498311)], null));
if(cljs.core.truth_(or__5002__auto__)){
return or__5002__auto__;
} else {
return (0);
}
})()], null);
});
dataspex.views.offset_pagination = (function dataspex$views$offset_pagination(opt,n){
return new cljs.core.PersistentVector(null, 3, 5, cljs.core.PersistentVector.EMPTY_NODE, [new cljs.core.Keyword("dataspex.actions","assoc-in","dataspex.actions/assoc-in",-674227967),new cljs.core.PersistentVector(null, 4, 5, cljs.core.PersistentVector.EMPTY_NODE, [new cljs.core.Keyword("dataspex","inspectee","dataspex/inspectee",-16162677).cljs$core$IFn$_invoke$arity$1(opt),new cljs.core.Keyword("dataspex","pagination","dataspex/pagination",1579821342),new cljs.core.Keyword("dataspex","path","dataspex/path",-1944358954).cljs$core$IFn$_invoke$arity$1(opt),new cljs.core.Keyword(null,"offset","offset",296498311)], null),n], null);
});
dataspex.views.update_folding = (function dataspex$views$update_folding(opt,path,v){
return new cljs.core.PersistentVector(null, 3, 5, cljs.core.PersistentVector.EMPTY_NODE, [new cljs.core.Keyword("dataspex.actions","assoc-in","dataspex.actions/assoc-in",-674227967),new cljs.core.PersistentVector(null, 3, 5, cljs.core.PersistentVector.EMPTY_NODE, [new cljs.core.Keyword("dataspex","inspectee","dataspex/inspectee",-16162677).cljs$core$IFn$_invoke$arity$1(opt),new cljs.core.Keyword("dataspex","folding","dataspex/folding",-1746748121),cljs.core.into.cljs$core$IFn$_invoke$arity$2(cljs.core.vec(new cljs.core.Keyword("dataspex","path","dataspex/path",-1944358954).cljs$core$IFn$_invoke$arity$1(opt)),path)], null),v], null);
});
dataspex.views.path_to = (function dataspex$views$path_to(var_args){
var G__68583 = arguments.length;
switch (G__68583) {
case 1:
return dataspex.views.path_to.cljs$core$IFn$_invoke$arity$1((arguments[(0)]));

break;
case 2:
return dataspex.views.path_to.cljs$core$IFn$_invoke$arity$2((arguments[(0)]),(arguments[(1)]));

break;
default:
throw (new Error(["Invalid arity: ",cljs.core.str.cljs$core$IFn$_invoke$arity$1(arguments.length)].join('')));

}
});

(dataspex.views.path_to.cljs$core$IFn$_invoke$arity$1 = (function (opt){
return dataspex.views.path_to.cljs$core$IFn$_invoke$arity$2(opt,cljs.core.PersistentVector.EMPTY);
}));

(dataspex.views.path_to.cljs$core$IFn$_invoke$arity$2 = (function (p__68591,xs){
var map__68592 = p__68591;
var map__68592__$1 = cljs.core.__destructure_map(map__68592);
var path = cljs.core.get.cljs$core$IFn$_invoke$arity$2(map__68592__$1,new cljs.core.Keyword("dataspex","path","dataspex/path",-1944358954));
return cljs.core.into.cljs$core$IFn$_invoke$arity$2(cljs.core.vec(path),xs);
}));

(dataspex.views.path_to.cljs$lang$maxFixedArity = 2);

dataspex.views.navigate_to = (function dataspex$views$navigate_to(opt,path){
return new cljs.core.PersistentVector(null, 1, 5, cljs.core.PersistentVector.EMPTY_NODE, [new cljs.core.PersistentVector(null, 3, 5, cljs.core.PersistentVector.EMPTY_NODE, [new cljs.core.Keyword("dataspex.actions","navigate","dataspex.actions/navigate",1833982734),new cljs.core.Keyword("dataspex","inspectee","dataspex/inspectee",-16162677).cljs$core$IFn$_invoke$arity$1(opt),path], null)], null);
});
dataspex.views.get_current_view = (function dataspex$views$get_current_view(v,p__68594){
var map__68595 = p__68594;
var map__68595__$1 = cljs.core.__destructure_map(map__68595);
var opt = map__68595__$1;
var path = cljs.core.get.cljs$core$IFn$_invoke$arity$2(map__68595__$1,new cljs.core.Keyword("dataspex","path","dataspex/path",-1944358954));
var view = cljs.core.get.cljs$core$IFn$_invoke$arity$2(map__68595__$1,new cljs.core.Keyword("dataspex","view","dataspex/view",-1507071672));
var default_view = cljs.core.get.cljs$core$IFn$_invoke$arity$2(map__68595__$1,new cljs.core.Keyword("dataspex","default-view","dataspex/default-view",2016721560));
var or__5002__auto__ = cljs.core.get.cljs$core$IFn$_invoke$arity$2(view,path);
if(cljs.core.truth_(or__5002__auto__)){
return or__5002__auto__;
} else {
var or__5002__auto____$1 = (((((!((v == null))))?((((false) || ((cljs.core.PROTOCOL_SENTINEL === v.dataspex$protocols$IPrefersView$))))?true:(((!v.cljs$lang$protocol_mask$partition$))?cljs.core.native_satisfies_QMARK_(dataspex.protocols.IPrefersView,v):false)):cljs.core.native_satisfies_QMARK_(dataspex.protocols.IPrefersView,v)))?(function (){var G__68608 = dataspex.protocols.get_preferred_view(v);
return (dataspex.views.views.cljs$core$IFn$_invoke$arity$1 ? dataspex.views.views.cljs$core$IFn$_invoke$arity$1(G__68608) : dataspex.views.views.call(null,G__68608));
})():null);
if(cljs.core.truth_(or__5002__auto____$1)){
return or__5002__auto____$1;
} else {
var or__5002__auto____$2 = (cljs.core.truth_(dataspex.data.supports_view_QMARK_(v,default_view,opt))?default_view:null);
if(cljs.core.truth_(or__5002__auto____$2)){
return or__5002__auto____$2;
} else {
var or__5002__auto____$3 = (cljs.core.truth_(dataspex.data.hiccup_QMARK_(v))?dataspex.views.source:null);
if(cljs.core.truth_(or__5002__auto____$3)){
return or__5002__auto____$3;
} else {
return dataspex.views.dictionary;
}
}
}
}
});
dataspex.views.get_render_data = (function dataspex$views$get_render_data(state,inspectee){
var inspector_state = cljs.core.get.cljs$core$IFn$_invoke$arity$2(state,inspectee);
var opt = cljs.core.merge.cljs$core$IFn$_invoke$arity$variadic(cljs.core.prim_seq.cljs$core$IFn$_invoke$arity$2([new cljs.core.PersistentArrayMap(null, 1, [new cljs.core.Keyword("dataspex","inspectee","dataspex/inspectee",-16162677),inspectee], null),cljs.core.select_keys(inspector_state,cljs.core.filter.cljs$core$IFn$_invoke$arity$2(cljs.core.comp.cljs$core$IFn$_invoke$arity$2(new cljs.core.PersistentHashSet(null, new cljs.core.PersistentArrayMap(null, 1, ["dataspex",null], null), null),cljs.core.namespace),cljs.core.keys(inspector_state)))], 0));
var data = dataspex.data.nav_in(cljs.core.get_in.cljs$core$IFn$_invoke$arity$2(state,new cljs.core.PersistentVector(null, 2, 5, cljs.core.PersistentVector.EMPTY_NODE, [inspectee,new cljs.core.Keyword(null,"val","val",128701612)], null)),new cljs.core.Keyword("dataspex","path","dataspex/path",-1944358954).cljs$core$IFn$_invoke$arity$1(opt));
var opt__$1 = cljs.core.assoc.cljs$core$IFn$_invoke$arity$3(opt,new cljs.core.Keyword("dataspex","view","dataspex/view",-1507071672),dataspex.views.get_current_view(data,opt));
return new cljs.core.PersistentArrayMap(null, 2, [new cljs.core.Keyword(null,"opt","opt",-794706369),opt__$1,new cljs.core.Keyword(null,"data","data",-232669377),dataspex.data.inspect.cljs$core$IFn$_invoke$arity$2(data,opt__$1)], null);
});

//# sourceMappingURL=dataspex.views.js.map

==> dataspex-2026.01.1.jar: public/app/cljs-runtime/dataspex.views.js <==
goog.provide('dataspex.views');
dataspex.views.inline = new cljs.core.Keyword("dataspex.views","inline","dataspex.views/inline",446683124);
dataspex.views.dictionary = new cljs.core.Keyword("dataspex.views","dictionary","dataspex.views/dictionary",-1052047971);
dataspex.views.table = new cljs.core.Keyword("dataspex.views","table","dataspex.views/table",394751342);
dataspex.views.source = new cljs.core.Keyword("dataspex.views","source","dataspex.views/source",-1131308809);
dataspex.views.views = cljs.core.PersistentHashSet.createAsIfByAssoc([dataspex.views.inline,dataspex.views.table,dataspex.views.dictionary,dataspex.views.source]);
dataspex.views.max_items = (100);
dataspex.views.max_count = (1000);
dataspex.views.get_pagination = (function dataspex$views$get_pagination(p__43166){
var map__43167 = p__43166;
var map__43167__$1 = cljs.core.__destructure_map(map__43167);
var pagination = cljs.core.get.cljs$core$IFn$_invoke$arity$2(map__43167__$1,new cljs.core.Keyword("dataspex","pagination","dataspex/pagination",1579821342));
var path = cljs.core.get.cljs$core$IFn$_invoke$arity$2(map__43167__$1,new cljs.core.Keyword("dataspex","path","dataspex/path",-1944358954));
return new cljs.core.PersistentArrayMap(null, 2, [new cljs.core.Keyword(null,"page-size","page-size",223836073),(function (){var or__5002__auto__ = cljs.core.get_in.cljs$core$IFn$_invoke$arity$2(pagination,new cljs.core.PersistentVector(null, 2, 5, cljs.core.PersistentVector.EMPTY_NODE, [path,new cljs.core.Keyword(null,"page-size","page-size",223836073)], null));
if(cljs.core.truth_(or__5002__auto__)){
return or__5002__auto__;
} else {
var or__5002__auto____$1 = new cljs.core.Keyword(null,"page-size","page-size",223836073).cljs$core$IFn$_invoke$arity$1(pagination);
if(cljs.core.truth_(or__5002__auto____$1)){
return or__5002__auto____$1;
} else {
return dataspex.views.max_items;
}
}
})(),new cljs.core.Keyword(null,"offset","offset",296498311),(function (){var or__5002__auto__ = cljs.core.get_in.cljs$core$IFn$_invoke$arity$2(pagination,new cljs.core.PersistentVector(null, 2, 5, cljs.core.PersistentVector.EMPTY_NODE, [path,new cljs.core.Keyword(null,"offset","offset",296498311)], null));
if(cljs.core.truth_(or__5002__auto__)){
return or__5002__auto__;
} else {
return (0);
}
})()], null);
});
dataspex.views.offset_pagination = (function dataspex$views$offset_pagination(opt,n){
return new cljs.core.PersistentVector(null, 3, 5, cljs.core.PersistentVector.EMPTY_NODE, [new cljs.core.Keyword("dataspex.actions","assoc-in","dataspex.actions/assoc-in",-674227967),new cljs.core.PersistentVector(null, 4, 5, cljs.core.PersistentVector.EMPTY_NODE, [new cljs.core.Keyword("dataspex","inspectee","dataspex/inspectee",-16162677).cljs$core$IFn$_invoke$arity$1(opt),new cljs.core.Keyword("dataspex","pagination","dataspex/pagination",1579821342),new cljs.core.Keyword("dataspex","path","dataspex/path",-1944358954).cljs$core$IFn$_invoke$arity$1(opt),new cljs.core.Keyword(null,"offset","offset",296498311)], null),n], null);
});
dataspex.views.update_folding = (function dataspex$views$update_folding(opt,path,v){
return new cljs.core.PersistentVector(null, 3, 5, cljs.core.PersistentVector.EMPTY_NODE, [new cljs.core.Keyword("dataspex.actions","assoc-in","dataspex.actions/assoc-in",-674227967),new cljs.core.PersistentVector(null, 3, 5, cljs.core.PersistentVector.EMPTY_NODE, [new cljs.core.Keyword("dataspex","inspectee","dataspex/inspectee",-16162677).cljs$core$IFn$_invoke$arity$1(opt),new cljs.core.Keyword("dataspex","folding","dataspex/folding",-1746748121),cljs.core.into.cljs$core$IFn$_invoke$arity$2(cljs.core.vec(new cljs.core.Keyword("dataspex","path","dataspex/path",-1944358954).cljs$core$IFn$_invoke$arity$1(opt)),path)], null),v], null);
});
dataspex.views.path_to = (function dataspex$views$path_to(var_args){
var G__43177 = arguments.length;
switch (G__43177) {
case 1:
return dataspex.views.path_to.cljs$core$IFn$_invoke$arity$1((arguments[(0)]));

break;
case 2:
return dataspex.views.path_to.cljs$core$IFn$_invoke$arity$2((arguments[(0)]),(arguments[(1)]));

break;
default:
throw (new Error(["Invalid arity: ",cljs.core.str.cljs$core$IFn$_invoke$arity$1(arguments.length)].join('')));

}
});

(dataspex.views.path_to.cljs$core$IFn$_invoke$arity$1 = (function (opt){
return dataspex.views.path_to.cljs$core$IFn$_invoke$arity$2(opt,cljs.core.PersistentVector.EMPTY);
}));

(dataspex.views.path_to.cljs$core$IFn$_invoke$arity$2 = (function (p__43183,xs){
var map__43184 = p__43183;
var map__43184__$1 = cljs.core.__destructure_map(map__43184);
var path = cljs.core.get.cljs$core$IFn$_invoke$arity$2(map__43184__$1,new cljs.core.Keyword("dataspex","path","dataspex/path",-1944358954));
return cljs.core.into.cljs$core$IFn$_invoke$arity$2(cljs.core.vec(path),xs);
}));

(dataspex.views.path_to.cljs$lang$maxFixedArity = 2);

dataspex.views.navigate_to = (function dataspex$views$navigate_to(opt,path){
return new cljs.core.PersistentVector(null, 1, 5, cljs.core.PersistentVector.EMPTY_NODE, [new cljs.core.PersistentVector(null, 3, 5, cljs.core.PersistentVector.EMPTY_NODE, [new cljs.core.Keyword("dataspex.actions","navigate","dataspex.actions/navigate",1833982734),new cljs.core.Keyword("dataspex","inspectee","dataspex/inspectee",-16162677).cljs$core$IFn$_invoke$arity$1(opt),path], null)], null);
});
dataspex.views.get_current_view = (function dataspex$views$get_current_view(v,p__43196){
var map__43197 = p__43196;
var map__43197__$1 = cljs.core.__destructure_map(map__43197);
var opt = map__43197__$1;
var path = cljs.core.get.cljs$core$IFn$_invoke$arity$2(map__43197__$1,new cljs.core.Keyword("dataspex","path","dataspex/path",-1944358954));
var view = cljs.core.get.cljs$core$IFn$_invoke$arity$2(map__43197__$1,new cljs.core.Keyword("dataspex","view","dataspex/view",-1507071672));
var default_view = cljs.core.get.cljs$core$IFn$_invoke$arity$2(map__43197__$1,new cljs.core.Keyword("dataspex","default-view","dataspex/default-view",2016721560));
var or__5002__auto__ = cljs.core.get.cljs$core$IFn$_invoke$arity$2(view,path);
if(cljs.core.truth_(or__5002__auto__)){
return or__5002__auto__;
} else {
var or__5002__auto____$1 = (((((!((v == null))))?((((false) || ((cljs.core.PROTOCOL_SENTINEL === v.dataspex$protocols$IPrefersView$))))?true:(((!v.cljs$lang$protocol_mask$partition$))?cljs.core.native_satisfies_QMARK_(dataspex.protocols.IPrefersView,v):false)):cljs.core.native_satisfies_QMARK_(dataspex.protocols.IPrefersView,v)))?(function (){var G__43201 = dataspex.protocols.get_preferred_view(v);
return (dataspex.views.views.cljs$core$IFn$_invoke$arity$1 ? dataspex.views.views.cljs$core$IFn$_invoke$arity$1(G__43201) : dataspex.views.views.call(null,G__43201));
})():null);
if(cljs.core.truth_(or__5002__auto____$1)){
return or__5002__auto____$1;
} else {
var or__5002__auto____$2 = (cljs.core.truth_(dataspex.data.supports_view_QMARK_(v,default_view,opt))?default_view:null);
if(cljs.core.truth_(or__5002__auto____$2)){
return or__5002__auto____$2;
} else {
var or__5002__auto____$3 = (cljs.core.truth_(dataspex.data.hiccup_QMARK_(v))?dataspex.views.source:null);
if(cljs.core.truth_(or__5002__auto____$3)){
return or__5002__auto____$3;
} else {
return dataspex.views.dictionary;
}
}
}
}
});
dataspex.views.get_data_w = (function dataspex$views$get_data_w(p__43207){
var map__43214 = p__43207;
var map__43214__$1 = cljs.core.__destructure_map(map__43214);
var client_window_size = cljs.core.get.cljs$core$IFn$_invoke$arity$2(map__43214__$1,new cljs.core.Keyword(null,"client-window-size","client-window-size",2134116614));
if(typeof client_window_size === 'number'){
return ((((function (){var x__5087__auto__ = client_window_size;
var y__5088__auto__ = (600);
return ((x__5087__auto__ > y__5088__auto__) ? x__5087__auto__ : y__5088__auto__);
})() - (120)) / (8)) | (0));
} else {
return (80);
}
});
dataspex.views.get_render_data = (function dataspex$views$get_render_data(state,inspectee){
var inspector_state = cljs.core.get.cljs$core$IFn$_invoke$arity$2(state,inspectee);
var opt = cljs.core.merge.cljs$core$IFn$_invoke$arity$variadic(cljs.core.prim_seq.cljs$core$IFn$_invoke$arity$2([new cljs.core.PersistentArrayMap(null, 1, [new cljs.core.Keyword("dataspex","inspectee","dataspex/inspectee",-16162677),inspectee], null),cljs.core.select_keys(inspector_state,cljs.core.filter.cljs$core$IFn$_invoke$arity$2(cljs.core.comp.cljs$core$IFn$_invoke$arity$2(new cljs.core.PersistentHashSet(null, new cljs.core.PersistentArrayMap(null, 1, ["dataspex",null], null), null),cljs.core.namespace),cljs.core.keys(inspector_state)))], 0));
var data = dataspex.data.nav_in(cljs.core.get_in.cljs$core$IFn$_invoke$arity$2(state,new cljs.core.PersistentVector(null, 2, 5, cljs.core.PersistentVector.EMPTY_NODE, [inspectee,new cljs.core.Keyword(null,"val","val",128701612)], null)),new cljs.core.Keyword("dataspex","path","dataspex/path",-1944358954).cljs$core$IFn$_invoke$arity$1(opt));
var opt__$1 = cljs.core.assoc.cljs$core$IFn$_invoke$arity$3(cljs.core.assoc.cljs$core$IFn$_invoke$arity$3(opt,new cljs.core.Keyword("dataspex","view","dataspex/view",-1507071672),dataspex.views.get_current_view(data,opt)),new cljs.core.Keyword("dataspex","summarize-above-w","dataspex/summarize-above-w",964197003),dataspex.views.get_data_w(state));
return new cljs.core.PersistentArrayMap(null, 2, [new cljs.core.Keyword(null,"opt","opt",-794706369),opt__$1,new cljs.core.Keyword(null,"data","data",-232669377),dataspex.data.inspect.cljs$core$IFn$_invoke$arity$2(data,opt__$1)], null);
});

//# sourceMappingURL=dataspex.views.js.map
